from selenium.webdriver.support import expected_conditions as exp
from selenium.webdriver.common.by import By
from selenium.webdriver.support.wait import WebDriverWait
from selenium.webdriver.common.action_chains import ActionChains
import time as t
from config.config import *

list = {
    'css': By.CSS_SELECTOR,
    'id': By.ID,
    'name': By.NAME,
    'xpath': By.XPATH,
    'link_text': By.LINK_TEXT,
    'partial_link_text': By.PARTIAL_LINK_TEXT,
    'tag': By.TAG_NAME,
    'class_name': By.CLASS_NAME,
}


class BasePage:
    """Page 封装的是公共类 所有测试类都基于该基类"""
    # Page encapsulates a common class. All test classes are based on that base class.
    def __init__(self,driver,path=None,timeout=10):
        """
        :param driver:
        :param timeout:
        :param path:
        """
        self.driver = driver

        self.url =  "http://www.baidu.com"
        #全局元素定位等待
        self.driver.implicitly_wait(timeout)

        self.open(path)



    def open(self,path=None):
        if path == None:
            url = None
        else:
            url = path
        if url != None:
            return self.driver.get(url)


    def run_script(self, js=None):
        """
        run JavaScript script
        """
        if js is None:
            raise ValueError("Please input js script")
        else:
            return self.driver.execute_script(js)



    def input_element(self,By,element,describe=None):
        """
        :param driver:
        :param By:
        :param element:
        :param valuse:
        :param describe:
        :return:
        """
        describe = describe
        bys = By
        if bys == By:
            return self.webDriverWait(driver=self.driver,by=(list[By],element))




    def webDriverWait(self,driver, by, timeout=5, pall=0.5):
        """
        driver 浏览器实例对象
        timeout 等待的实际时间
        poll 刷新间隔
        :return:
        """
        try:
            element = WebDriverWait(driver, timeout, pall).until(
                # 直到被定位的元素被找到
                exp.presence_of_element_located(by)
            )
            return element
        except:
            print("元素定位失败,你可以尝试修改下 %s" % str(by))

    def button_element(self,By,element,describe=None):
        desctibe = describe
        if By == By:
            return self.webDriverWait(driver=self.driver,by=(list[By],element)).click()


    def cleanup(self):
        self.imgs = []
        self.imgs.append(self.driver.get_screenshot_as_base64())
        return self.imgs

    """浏览器操作封装"""

    def max(self):
        """浏览器最大化"""
        try:
            return   self.driver.maximize_window()
        except Exception:
            print('窗口大小设置，错误！！！')

    def set_size(self,s,e):
        """参数化设置window大小"""
        try:
            test = self.driver.set_window_size(s, e)
            return test
        except Exception:
            print('浏览器窗口参数错误！！！')

    def back(self):
        """后退"""
        try:
            test = self.driver.back()
            return test
        except Exception:
            print('浏览器后退执行错误！！！')

    def ward(self):
        """前进"""
        test = self.driver.forward()
        return test

    def js(self):
        test = "var s=document.documentElement.scrollTop=1000"
        print(test)
        return  self.driver.execute_script(test)

    def screenshot(self):
        filename = t.strftime("%H-%M-%S")
        try:


            self.driver.save_screenshot(SCREENSHOT_PATH+r"\%s.png"%filename)
        except:
            print("截取图片好像出了点问题哦！你可以尝试修改下 %s 文件路径或文件名"%filename)

    def resh(self):
        test = self.driver.refresh()
        return test

    def quit(self):
        """关闭"""
        test = self.driver.quit()
        return test

    def handle(self):
        """获得当前窗口"""
        test = self.driver.current_window_handle()
        return test

    def handles(self,s):
        """返回的所有窗口的句柄到当前会话"""
        test = self.driver.window_handles(s)

        return test

    def window(self, handles):
        """窗口切换"""
        test = self.driver.switch_to_window(handles)
        return test

    def frame(self, frames):
        """框架切换"""
        return self.driver.switch_to.frame(frames)

    def context_click(driver, a):
        """右击"""
        ActionChains(driver).context_click(a).perform()

    def double_click(self, s):
        """双击"""
        return  ActionChains(self.driver).double_click(s).perform()

    def drag_and_drop(self, source, target):
        """拖动"""
        return ActionChains(self.driver).drag_and_drop(source, target).perform()

    def move_to_element(self, r):
        """鼠标悬停在元素上"""
        return ActionChains(self.driver).move_to_element(r).perform()

    def click_and_hold(self, source):
        """按下鼠标左键在一个元素上"""
        ActionChains(self.driver).click_and_hold(source).perform()

    def implicitly_wait(self, s):
        """隐式等待"""
        self.driver.implicitly_wait(s)

    def WebDriverWait(self, d):
        """显式等待"""
        self.driver.WebDriverWait(d)










